@@ -1,90 +1,3 @@
-=encoding UTF-8
-
-=head1 NAME
-
-Image::CairoSVG - render SVG into a Cairo surface
-
-=head1 SYNOPSIS
-
-This example converts an SVG into a PNG:
-
-    use Cairo;
-    use Image::CairoSVG;
-    my $surface = Cairo::ImageSurface->new ();
-    my $cairosvg = Image::CairoSVG->new (
-        surface => $surface,
-    );
-    $cairosvg->render ('file.svg');
-
-=head1 DESCRIPTION
-
-=head1 METHODS
-
-=head2 new
-
-    my $cairosvg = Image::CairoSVG->new ();
-
-Use default surface.
-
-    my $cairosvg = Image::CairoSVG->new (surface => $surface);
-
-With a surface
-
-Not implemented yet:
-
-    my $cairosvg = Image::CairoSVG->new (context => $cr);
-
-=head2 render
-
-    $cairosvg->render ('some.svg');
-
-Draw an SVG file into a Cairo surface.
-
-=head2 line
-
-    $cairosvg->line (%attr);
-
-Given SVG input of the form C<< <line > >>, this renders it onto the
-Cairo surface.
-
-=head2 path
-
-    $cairosvg->path (%attr);
-
-=head2 rect
-
-    $cairosvg->rect (%attr);
-
-=head1 Dependencies
-
-=over
-
-=item L<Cairo>
-
-This is the renderer.
-
-=item L<Image::SVG::Path>
-
-This is used for parsing the "path" information of the SVG.
-
-=item L<XML::Parser>
-
-This is used for parsing the SVG itself.
-
-=back
-
-=head1 SEE ALSO
-
-=head2 CPAN
-
-=head2 Other
-
-=head3 CairoSVG
-
-L<http://cairosvg.org/|CairoSVG> is a Python SVG renderer in Cairo.
-
-=cut
-
 package Image::CairoSVG;
 require Exporter;
 @ISA = qw(Exporter);
@@ -99,22 +12,11 @@ use XML::Parser;
 use Cairo;
 use Image::SVG::Path qw/extract_path_info create_path_string/;
 use constant M_PI => 3.14159265358979;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our $default_surface_type = 'argb32';
 our $default_surface_size = 100;
 
-=head2 new
-
-    my $cairosvg = Image::CairoSVG->new (
-        surface => Cairo::ImageSurface->create ('argb32', 100, 100)
-    );
-
-If a surface is not provided, this creates a L<Cairo::ImageSurface> of
-dimensions 100 by 100 of rgba format.
-
-=cut
-
 sub new
 {
     my ($class, %options) = @_;
@@ -144,14 +46,6 @@ sub new
     return bless $self;
 }
 
-=head2 render
-
-    $self->render ($file);
-
-Render F<$file> onto the Cairo surface of C<$self>.
-
-=cut
-
 sub render
 {
     my ($self, $file) = @_;
@@ -229,12 +123,6 @@ sub handle_start
 
 }
 
-=head2 rect
-
-    $cairosvg->rect (%attr);
-
-=cut
-
 sub rect
 {
     my ($self, %attr) = @_;
@@ -251,12 +139,6 @@ sub rect
     $self->do_svg_attr (%attr);
 }
 
-=head2 ellipse
-
-    $cairosvg->ellipse (%attr);
-
-=cut
-
 sub ellipse
 {
     my ($self, %attr) = @_;
@@ -283,12 +165,6 @@ sub ellipse
     $self->do_svg_attr (%attr);
 }
 
-=head2 circle
-
-    $cairosvg->circle (%attr);
-
-=cut
-
 sub circle
 {
     my ($self, %attr) = @_;
@@ -306,12 +182,6 @@ sub circle
     $self->do_svg_attr (%attr);
 }
 
-=head2 polygon
-
-    $cairosvg->polygon (%attr);
-
-=cut
-
 sub polygon
 {
     my ($self, %attr) = @_;
@@ -336,15 +206,6 @@ sub polygon
     $self->do_svg_attr (%attr);
 }
 
-=head2 path
-
-    $cairosvg->path (%attr);
-
-Given an SVG path element, send its attribute key / value pairs as
-C<%attr> to render into the Cairo surface of C<$cairosvg>.
-
-=cut
-
 sub path
 {
     my ($self, %attr) = @_;
@@ -517,12 +378,11 @@ sub quadbez
     my ($cr, $p2, $p3) = @_;
 
     if (! $cr->has_current_point ()) {
-	# This is a bug, there is always a current point when
-	# rendering an SVG path.
+	# This indicates a bug has happened, because there is always a
+	# current point when rendering an SVG path.
 	die "Invalid drawing of quadratic bezier without a current point";
     }
 
-
     my @p1 = $cr->get_current_point ();
     my @p2_1;
     my @p2_2;
@@ -537,14 +397,6 @@ sub quadbez
     $cr->curve_to (@p2_1, @p2_2, @$p3);
 }
 
-=head2 line
-
-    $cairosvg->line (%attr);
-
-Render an SVG line onto the surface specified by C<$cairosvg>.
-
-=cut
-
 sub line
 {
     my ($self, %attr) = @_;
@@ -691,23 +543,3 @@ sub rotate
 
 1;
 
-=head1 BUGS
-
-This module is a "least effort" attempt to get the parts of SVG which
-the author needs rendered rendered. It doesn't even pretend to be a
-full SVG renderer. So if you find the module doesn't do some part of
-SVG which you want done, please add that to the module and if possible
-contribute your addition to this module via git.
-
-=head1 LICENCE, COPYRIGHT, AUTHOR
-
-Copyright 2014 Ben Bullock bkb@cpan.org. Licence = Perl (Artistic + GNU).
-
-Some parts of the module (specifically the SVG arc drawing code) are
-translations from the above-mentioned Python program "cairosvg", which
-is under the "GNU LESSER GENERAL PUBLIC LICENSE Version 3, 29 June
-2007". I'm not really sure how or if this affects the code, but just
-in case it causes legal issues for someone downstream, I'm mentioning
-it here.
-
-=cut
